@@ -7,7 +7,7 @@ function bigx_do_curse(sent)
     if sent==0 then
         u61_send_curse(ID_CURSE_BIGX)
     else
-        u61_reset_block()
+        u61_clear_block()
         u61_add_item(0,0,7) 
         u61_add_item(-1,-1,7) 
         u61_add_item(-1,1,7) 
