@@ -7,7 +7,7 @@ function boost_do_curse(sent)
     if sent==0 then
         u61_send_curse(ID_CURSE_BOOST)
     else
-        u61_register_curse(ID_CURSE_BOOST,5)
+        u61_register_curse(ID_CURSE_BOOST,500,0)
     end
 end
 
