@@ -7,7 +7,7 @@ function morecolors_do_curse(sent)
     if sent==0 then
         u61_send_curse(ID_CURSE_MORECOLORS)
     else
-        u61_register_curse(ID_CURSE_MORECOLORS,300)
+        u61_register_curse(ID_CURSE_MORECOLORS,30000,0)
     end
 end
 
