@@ -7,7 +7,7 @@ function shuffle_do_curse(sent)
     if sent==0 then
         u61_send_curse(ID_CURSE_SHUFFLE)
     else
-        u61_register_curse(ID_CURSE_SHUFFLE,2)
+        u61_register_curse(ID_CURSE_SHUFFLE,200,0)
     end
 end
 
