@@ -69,7 +69,7 @@ function user_move_down()
 end
 
 function user_use_antidote()
-    u61_cancel_curse(u61_get_oldest_curse())
+    u61_cancel_curse(u61_get_oldest_curse(0))
 end
 
 -- pattern match -------------------------------------------------------------
@@ -144,10 +144,18 @@ function user_get_curse_name(num)
     return name
 end
 
--- other functions -----------------------------------------------------------
+-- callback functions --------------------------------------------------------
 
-function user_time_callback()
-    u61_add_score(10)
+function user_time_callback_1()
+    u61_add_score(1)
+end
+
+function user_time_callback_10()
     wind_time_callback()
 end
 
+function user_time_callback_100()
+
+end
+
+
